@@ -1,5 +1,5 @@
 package Mail::DMARC;
-our $VERSION = '1.20150908'; # VERSION
+our $VERSION = '1.20170222'; # VERSION
 use strict;
 use warnings;
 
@@ -130,6 +130,7 @@ sub _from_mail_dkim {
                 human_result => $s->result_detail,
             );
     }
+    return;
 }
 
 sub _unwrap {
@@ -274,6 +275,7 @@ sub init {
     # used for testing
     my $self = shift;
     map { delete $self->{$_} } qw/ spf spf_ar dkim dkim_ar /;
+    return;
 }
 
 1;
@@ -290,7 +292,7 @@ Mail::DMARC - Perl implementation of DMARC
 
 =head1 VERSION
 
-version 1.20150908
+version 1.20170222
 
 =head1 SYNOPSIS
 
@@ -379,8 +381,6 @@ outgoing reports will have null values for report.uuid and report_record.count
 
 =for markdown [![Coverage Status](https://coveralls.io/repos/msimerson/mail-dmarc/badge.svg)](https://coveralls.io/r/msimerson/mail-dmarc)
 
-=for markdown [![Stories in Ready](https://badge.waffle.io/msimerson/mail-dmarc.png?label=ready&title=Ready)](https://waffle.io/msimerson/mail-dmarc)
-
 =head1 CLASSES
 
 L<Mail::DMARC> - the perl interface for DMARC
@@ -616,7 +616,7 @@ Davide Migliavacca <shari@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Benny Pedersen Making GitHub Delicious. Marc Bradshaw Priyadi Iman Nurcahyo Ricardo Signes
+=for stopwords Benny Pedersen Jean Paul Galea Making GitHub Delicious. Marc Bradshaw Priyadi Iman Nurcahyo Ricardo Signes
 
 =over 4
 
@@ -626,6 +626,14 @@ Benny Pedersen <me@junc.eu>
 
 =item *
 
+Jean Paul Galea <jeanpaul@yubico.com>
+
+=item *
+
+Jean Paul Galea <jp@galea.se>
+
+=item *
+
 Making GitHub Delicious. <iron@waffle.io>
 
 =item *
